# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class EmergencyFundCalculatorRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'frequency_unit': 'str',
        'aggregation_account_ids': 'list[str]',
        'food_costs': 'float',
        'housing_cost': 'float',
        'debt_payments': 'float',
        'client_id': 'str',
        'account_ids': 'list[str]',
        'utility_payments': 'float',
        'insurance_payments': 'float',
        'transportation_costs': 'float',
        'lookback_periods': 'int',
        'emergency_fund_duration': 'int',
        'interest_rate': 'float',
        'telecom_payments': 'float',
        'savings_horizon': 'list[int]',
        'other_expenses': 'object',
        'current_emergency_fund_balance': 'float'
    }

    attribute_map = {
        'frequency_unit': 'frequency_unit',
        'aggregation_account_ids': 'aggregation_account_ids',
        'food_costs': 'food_costs',
        'housing_cost': 'housing_cost',
        'debt_payments': 'debt_payments',
        'client_id': 'client_id',
        'account_ids': 'account_ids',
        'utility_payments': 'utility_payments',
        'insurance_payments': 'insurance_payments',
        'transportation_costs': 'transportation_costs',
        'lookback_periods': 'lookback_periods',
        'emergency_fund_duration': 'emergency_fund_duration',
        'interest_rate': 'interest_rate',
        'telecom_payments': 'telecom_payments',
        'savings_horizon': 'savings_horizon',
        'other_expenses': 'other_expenses',
        'current_emergency_fund_balance': 'current_emergency_fund_balance'
    }

    def __init__(self, frequency_unit='month', aggregation_account_ids=None, food_costs=0.0, housing_cost=0.0, debt_payments=0.0, client_id=None, account_ids=None, utility_payments=0.0, insurance_payments=0.0, transportation_costs=0.0, lookback_periods=3, emergency_fund_duration=None, interest_rate=0.0, telecom_payments=0.0, savings_horizon=None, other_expenses=None, current_emergency_fund_balance=0.0):  # noqa: E501
        """EmergencyFundCalculatorRequest - a model defined in Swagger"""  # noqa: E501

        self._frequency_unit = None
        self._aggregation_account_ids = None
        self._food_costs = None
        self._housing_cost = None
        self._debt_payments = None
        self._client_id = None
        self._account_ids = None
        self._utility_payments = None
        self._insurance_payments = None
        self._transportation_costs = None
        self._lookback_periods = None
        self._emergency_fund_duration = None
        self._interest_rate = None
        self._telecom_payments = None
        self._savings_horizon = None
        self._other_expenses = None
        self._current_emergency_fund_balance = None
        self.discriminator = None

        if frequency_unit is not None:
            self.frequency_unit = frequency_unit
        if aggregation_account_ids is not None:
            self.aggregation_account_ids = aggregation_account_ids
        if food_costs is not None:
            self.food_costs = food_costs
        if housing_cost is not None:
            self.housing_cost = housing_cost
        if debt_payments is not None:
            self.debt_payments = debt_payments
        if client_id is not None:
            self.client_id = client_id
        if account_ids is not None:
            self.account_ids = account_ids
        if utility_payments is not None:
            self.utility_payments = utility_payments
        if insurance_payments is not None:
            self.insurance_payments = insurance_payments
        if transportation_costs is not None:
            self.transportation_costs = transportation_costs
        if lookback_periods is not None:
            self.lookback_periods = lookback_periods
        self.emergency_fund_duration = emergency_fund_duration
        if interest_rate is not None:
            self.interest_rate = interest_rate
        if telecom_payments is not None:
            self.telecom_payments = telecom_payments
        if savings_horizon is not None:
            self.savings_horizon = savings_horizon
        if other_expenses is not None:
            self.other_expenses = other_expenses
        if current_emergency_fund_balance is not None:
            self.current_emergency_fund_balance = current_emergency_fund_balance

    @property
    def frequency_unit(self):
        """Gets the frequency_unit of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The frequency_unit of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: str
        """
        return self._frequency_unit

    @frequency_unit.setter
    def frequency_unit(self, frequency_unit):
        """Sets the frequency_unit of this EmergencyFundCalculatorRequest.


        :param frequency_unit: The frequency_unit of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["year", "six_months", "quarter", "month", "two_weeks", "week"]  # noqa: E501
        if frequency_unit not in allowed_values:
            raise ValueError(
                "Invalid value for `frequency_unit` ({0}), must be one of {1}"  # noqa: E501
                .format(frequency_unit, allowed_values)
            )

        self._frequency_unit = frequency_unit

    @property
    def aggregation_account_ids(self):
        """Gets the aggregation_account_ids of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The aggregation_account_ids of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._aggregation_account_ids

    @aggregation_account_ids.setter
    def aggregation_account_ids(self, aggregation_account_ids):
        """Sets the aggregation_account_ids of this EmergencyFundCalculatorRequest.


        :param aggregation_account_ids: The aggregation_account_ids of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: list[str]
        """

        self._aggregation_account_ids = aggregation_account_ids

    @property
    def food_costs(self):
        """Gets the food_costs of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The food_costs of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._food_costs

    @food_costs.setter
    def food_costs(self, food_costs):
        """Sets the food_costs of this EmergencyFundCalculatorRequest.


        :param food_costs: The food_costs of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if food_costs is not None and food_costs < 0:  # noqa: E501
            raise ValueError("Invalid value for `food_costs`, must be a value greater than or equal to `0`")  # noqa: E501

        self._food_costs = food_costs

    @property
    def housing_cost(self):
        """Gets the housing_cost of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The housing_cost of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._housing_cost

    @housing_cost.setter
    def housing_cost(self, housing_cost):
        """Sets the housing_cost of this EmergencyFundCalculatorRequest.


        :param housing_cost: The housing_cost of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if housing_cost is not None and housing_cost < 0:  # noqa: E501
            raise ValueError("Invalid value for `housing_cost`, must be a value greater than or equal to `0`")  # noqa: E501

        self._housing_cost = housing_cost

    @property
    def debt_payments(self):
        """Gets the debt_payments of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The debt_payments of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._debt_payments

    @debt_payments.setter
    def debt_payments(self, debt_payments):
        """Sets the debt_payments of this EmergencyFundCalculatorRequest.


        :param debt_payments: The debt_payments of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if debt_payments is not None and debt_payments < 0:  # noqa: E501
            raise ValueError("Invalid value for `debt_payments`, must be a value greater than or equal to `0`")  # noqa: E501

        self._debt_payments = debt_payments

    @property
    def client_id(self):
        """Gets the client_id of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The client_id of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this EmergencyFundCalculatorRequest.


        :param client_id: The client_id of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def account_ids(self):
        """Gets the account_ids of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The account_ids of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_ids

    @account_ids.setter
    def account_ids(self, account_ids):
        """Sets the account_ids of this EmergencyFundCalculatorRequest.


        :param account_ids: The account_ids of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: list[str]
        """

        self._account_ids = account_ids

    @property
    def utility_payments(self):
        """Gets the utility_payments of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The utility_payments of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._utility_payments

    @utility_payments.setter
    def utility_payments(self, utility_payments):
        """Sets the utility_payments of this EmergencyFundCalculatorRequest.


        :param utility_payments: The utility_payments of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if utility_payments is not None and utility_payments < 0:  # noqa: E501
            raise ValueError("Invalid value for `utility_payments`, must be a value greater than or equal to `0`")  # noqa: E501

        self._utility_payments = utility_payments

    @property
    def insurance_payments(self):
        """Gets the insurance_payments of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The insurance_payments of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._insurance_payments

    @insurance_payments.setter
    def insurance_payments(self, insurance_payments):
        """Sets the insurance_payments of this EmergencyFundCalculatorRequest.


        :param insurance_payments: The insurance_payments of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if insurance_payments is not None and insurance_payments < 0:  # noqa: E501
            raise ValueError("Invalid value for `insurance_payments`, must be a value greater than or equal to `0`")  # noqa: E501

        self._insurance_payments = insurance_payments

    @property
    def transportation_costs(self):
        """Gets the transportation_costs of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The transportation_costs of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._transportation_costs

    @transportation_costs.setter
    def transportation_costs(self, transportation_costs):
        """Sets the transportation_costs of this EmergencyFundCalculatorRequest.


        :param transportation_costs: The transportation_costs of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if transportation_costs is not None and transportation_costs < 0:  # noqa: E501
            raise ValueError("Invalid value for `transportation_costs`, must be a value greater than or equal to `0`")  # noqa: E501

        self._transportation_costs = transportation_costs

    @property
    def lookback_periods(self):
        """Gets the lookback_periods of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The lookback_periods of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: int
        """
        return self._lookback_periods

    @lookback_periods.setter
    def lookback_periods(self, lookback_periods):
        """Sets the lookback_periods of this EmergencyFundCalculatorRequest.


        :param lookback_periods: The lookback_periods of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: int
        """
        if lookback_periods is not None and lookback_periods < 1:  # noqa: E501
            raise ValueError("Invalid value for `lookback_periods`, must be a value greater than or equal to `1`")  # noqa: E501

        self._lookback_periods = lookback_periods

    @property
    def emergency_fund_duration(self):
        """Gets the emergency_fund_duration of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The emergency_fund_duration of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: int
        """
        return self._emergency_fund_duration

    @emergency_fund_duration.setter
    def emergency_fund_duration(self, emergency_fund_duration):
        """Sets the emergency_fund_duration of this EmergencyFundCalculatorRequest.


        :param emergency_fund_duration: The emergency_fund_duration of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: int
        """
        if emergency_fund_duration is None:
            raise ValueError("Invalid value for `emergency_fund_duration`, must not be `None`")  # noqa: E501
        if emergency_fund_duration is not None and emergency_fund_duration < 1:  # noqa: E501
            raise ValueError("Invalid value for `emergency_fund_duration`, must be a value greater than or equal to `1`")  # noqa: E501

        self._emergency_fund_duration = emergency_fund_duration

    @property
    def interest_rate(self):
        """Gets the interest_rate of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The interest_rate of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._interest_rate

    @interest_rate.setter
    def interest_rate(self, interest_rate):
        """Sets the interest_rate of this EmergencyFundCalculatorRequest.


        :param interest_rate: The interest_rate of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if interest_rate is not None and interest_rate < 0:  # noqa: E501
            raise ValueError("Invalid value for `interest_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._interest_rate = interest_rate

    @property
    def telecom_payments(self):
        """Gets the telecom_payments of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The telecom_payments of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._telecom_payments

    @telecom_payments.setter
    def telecom_payments(self, telecom_payments):
        """Sets the telecom_payments of this EmergencyFundCalculatorRequest.


        :param telecom_payments: The telecom_payments of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if telecom_payments is not None and telecom_payments < 0:  # noqa: E501
            raise ValueError("Invalid value for `telecom_payments`, must be a value greater than or equal to `0`")  # noqa: E501

        self._telecom_payments = telecom_payments

    @property
    def savings_horizon(self):
        """Gets the savings_horizon of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The savings_horizon of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._savings_horizon

    @savings_horizon.setter
    def savings_horizon(self, savings_horizon):
        """Sets the savings_horizon of this EmergencyFundCalculatorRequest.


        :param savings_horizon: The savings_horizon of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: list[int]
        """

        self._savings_horizon = savings_horizon

    @property
    def other_expenses(self):
        """Gets the other_expenses of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The other_expenses of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: object
        """
        return self._other_expenses

    @other_expenses.setter
    def other_expenses(self, other_expenses):
        """Sets the other_expenses of this EmergencyFundCalculatorRequest.


        :param other_expenses: The other_expenses of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: object
        """

        self._other_expenses = other_expenses

    @property
    def current_emergency_fund_balance(self):
        """Gets the current_emergency_fund_balance of this EmergencyFundCalculatorRequest.  # noqa: E501


        :return: The current_emergency_fund_balance of this EmergencyFundCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._current_emergency_fund_balance

    @current_emergency_fund_balance.setter
    def current_emergency_fund_balance(self, current_emergency_fund_balance):
        """Sets the current_emergency_fund_balance of this EmergencyFundCalculatorRequest.


        :param current_emergency_fund_balance: The current_emergency_fund_balance of this EmergencyFundCalculatorRequest.  # noqa: E501
        :type: float
        """
        if current_emergency_fund_balance is not None and current_emergency_fund_balance < 0:  # noqa: E501
            raise ValueError("Invalid value for `current_emergency_fund_balance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._current_emergency_fund_balance = current_emergency_fund_balance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmergencyFundCalculatorRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmergencyFundCalculatorRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.business_financial_management_api import BusinessFinancialManagementApi  # noqa: E501
from proton_api.rest import ApiException


class TestBusinessFinancialManagementApi(unittest.TestCase):
    """BusinessFinancialManagementApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.business_financial_management_api.BusinessFinancialManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_financial_health_check(self):
        """Test case for business_financial_health_check

        Business Financial Health Check  # noqa: E501
        """
        pass

    def test_cash_analysis(self):
        """Test case for cash_analysis

        Cash Analysis  # noqa: E501
        """
        pass

    def test_customer_analysis(self):
        """Test case for customer_analysis

        Customer Analysis  # noqa: E501
        """
        pass

    def test_financial_statement_analysis(self):
        """Test case for financial_statement_analysis

        Financial Statement Analysis  # noqa: E501
        """
        pass

    def test_invoice_analysis(self):
        """Test case for invoice_analysis

        Invoice Analysis  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "hydrogen_proton_api"
VERSION = "1.8.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="Hydrogen Proton API",
    author_email="info@hydrogenplatform.com",
    url="",
    keywords=["Swagger", "Hydrogen Proton API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Financial engineering module of Hydrogen Atom  # noqa: E501
    """
)



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RetirementCalculatorPercentCoveredRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'retirement_savings': 'float',
        'aggregation_account_ids': 'list[str]',
        'retirement_age': 'int',
        'retirement_income': 'float',
        'retirement_expenses': 'float',
        'current_age': 'int',
        'account_ids': 'list[str]',
        'retirement_tax': 'float',
        'inflation_rate': 'float',
        'death_age': 'int',
        'portfolio_return': 'float',
        'deposit_schedule': 'CalculatorDepositSchedule1'
    }

    attribute_map = {
        'retirement_savings': 'retirement_savings',
        'aggregation_account_ids': 'aggregation_account_ids',
        'retirement_age': 'retirement_age',
        'retirement_income': 'retirement_income',
        'retirement_expenses': 'retirement_expenses',
        'current_age': 'current_age',
        'account_ids': 'account_ids',
        'retirement_tax': 'retirement_tax',
        'inflation_rate': 'inflation_rate',
        'death_age': 'death_age',
        'portfolio_return': 'portfolio_return',
        'deposit_schedule': 'deposit_schedule'
    }

    def __init__(self, retirement_savings=0.0, aggregation_account_ids=None, retirement_age=65, retirement_income=0.0, retirement_expenses=None, current_age=None, account_ids=None, retirement_tax=0.0, inflation_rate=0.0, death_age=None, portfolio_return=None, deposit_schedule=None):  # noqa: E501
        """RetirementCalculatorPercentCoveredRequest - a model defined in Swagger"""  # noqa: E501

        self._retirement_savings = None
        self._aggregation_account_ids = None
        self._retirement_age = None
        self._retirement_income = None
        self._retirement_expenses = None
        self._current_age = None
        self._account_ids = None
        self._retirement_tax = None
        self._inflation_rate = None
        self._death_age = None
        self._portfolio_return = None
        self._deposit_schedule = None
        self.discriminator = None

        if retirement_savings is not None:
            self.retirement_savings = retirement_savings
        if aggregation_account_ids is not None:
            self.aggregation_account_ids = aggregation_account_ids
        if retirement_age is not None:
            self.retirement_age = retirement_age
        if retirement_income is not None:
            self.retirement_income = retirement_income
        self.retirement_expenses = retirement_expenses
        self.current_age = current_age
        if account_ids is not None:
            self.account_ids = account_ids
        if retirement_tax is not None:
            self.retirement_tax = retirement_tax
        if inflation_rate is not None:
            self.inflation_rate = inflation_rate
        self.death_age = death_age
        self.portfolio_return = portfolio_return
        if deposit_schedule is not None:
            self.deposit_schedule = deposit_schedule

    @property
    def retirement_savings(self):
        """Gets the retirement_savings of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The retirement_savings of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._retirement_savings

    @retirement_savings.setter
    def retirement_savings(self, retirement_savings):
        """Sets the retirement_savings of this RetirementCalculatorPercentCoveredRequest.


        :param retirement_savings: The retirement_savings of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if retirement_savings is not None and retirement_savings < 0:  # noqa: E501
            raise ValueError("Invalid value for `retirement_savings`, must be a value greater than or equal to `0`")  # noqa: E501

        self._retirement_savings = retirement_savings

    @property
    def aggregation_account_ids(self):
        """Gets the aggregation_account_ids of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The aggregation_account_ids of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._aggregation_account_ids

    @aggregation_account_ids.setter
    def aggregation_account_ids(self, aggregation_account_ids):
        """Sets the aggregation_account_ids of this RetirementCalculatorPercentCoveredRequest.


        :param aggregation_account_ids: The aggregation_account_ids of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: list[str]
        """

        self._aggregation_account_ids = aggregation_account_ids

    @property
    def retirement_age(self):
        """Gets the retirement_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The retirement_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: int
        """
        return self._retirement_age

    @retirement_age.setter
    def retirement_age(self, retirement_age):
        """Sets the retirement_age of this RetirementCalculatorPercentCoveredRequest.


        :param retirement_age: The retirement_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: int
        """
        if retirement_age is not None and retirement_age < 0:  # noqa: E501
            raise ValueError("Invalid value for `retirement_age`, must be a value greater than or equal to `0`")  # noqa: E501

        self._retirement_age = retirement_age

    @property
    def retirement_income(self):
        """Gets the retirement_income of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The retirement_income of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._retirement_income

    @retirement_income.setter
    def retirement_income(self, retirement_income):
        """Sets the retirement_income of this RetirementCalculatorPercentCoveredRequest.


        :param retirement_income: The retirement_income of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if retirement_income is not None and retirement_income < 0:  # noqa: E501
            raise ValueError("Invalid value for `retirement_income`, must be a value greater than or equal to `0`")  # noqa: E501

        self._retirement_income = retirement_income

    @property
    def retirement_expenses(self):
        """Gets the retirement_expenses of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The retirement_expenses of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._retirement_expenses

    @retirement_expenses.setter
    def retirement_expenses(self, retirement_expenses):
        """Sets the retirement_expenses of this RetirementCalculatorPercentCoveredRequest.


        :param retirement_expenses: The retirement_expenses of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if retirement_expenses is None:
            raise ValueError("Invalid value for `retirement_expenses`, must not be `None`")  # noqa: E501
        if retirement_expenses is not None and retirement_expenses < 0:  # noqa: E501
            raise ValueError("Invalid value for `retirement_expenses`, must be a value greater than or equal to `0`")  # noqa: E501

        self._retirement_expenses = retirement_expenses

    @property
    def current_age(self):
        """Gets the current_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The current_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: int
        """
        return self._current_age

    @current_age.setter
    def current_age(self, current_age):
        """Sets the current_age of this RetirementCalculatorPercentCoveredRequest.


        :param current_age: The current_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: int
        """
        if current_age is None:
            raise ValueError("Invalid value for `current_age`, must not be `None`")  # noqa: E501
        if current_age is not None and current_age < 0:  # noqa: E501
            raise ValueError("Invalid value for `current_age`, must be a value greater than or equal to `0`")  # noqa: E501

        self._current_age = current_age

    @property
    def account_ids(self):
        """Gets the account_ids of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The account_ids of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_ids

    @account_ids.setter
    def account_ids(self, account_ids):
        """Sets the account_ids of this RetirementCalculatorPercentCoveredRequest.


        :param account_ids: The account_ids of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: list[str]
        """

        self._account_ids = account_ids

    @property
    def retirement_tax(self):
        """Gets the retirement_tax of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The retirement_tax of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._retirement_tax

    @retirement_tax.setter
    def retirement_tax(self, retirement_tax):
        """Sets the retirement_tax of this RetirementCalculatorPercentCoveredRequest.


        :param retirement_tax: The retirement_tax of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if retirement_tax is not None and retirement_tax > 1:  # noqa: E501
            raise ValueError("Invalid value for `retirement_tax`, must be a value less than or equal to `1`")  # noqa: E501
        if retirement_tax is not None and retirement_tax < 0:  # noqa: E501
            raise ValueError("Invalid value for `retirement_tax`, must be a value greater than or equal to `0`")  # noqa: E501

        self._retirement_tax = retirement_tax

    @property
    def inflation_rate(self):
        """Gets the inflation_rate of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The inflation_rate of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._inflation_rate

    @inflation_rate.setter
    def inflation_rate(self, inflation_rate):
        """Sets the inflation_rate of this RetirementCalculatorPercentCoveredRequest.


        :param inflation_rate: The inflation_rate of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if inflation_rate is not None and inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._inflation_rate = inflation_rate

    @property
    def death_age(self):
        """Gets the death_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The death_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: int
        """
        return self._death_age

    @death_age.setter
    def death_age(self, death_age):
        """Sets the death_age of this RetirementCalculatorPercentCoveredRequest.


        :param death_age: The death_age of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: int
        """
        if death_age is None:
            raise ValueError("Invalid value for `death_age`, must not be `None`")  # noqa: E501
        if death_age is not None and death_age < 0:  # noqa: E501
            raise ValueError("Invalid value for `death_age`, must be a value greater than or equal to `0`")  # noqa: E501

        self._death_age = death_age

    @property
    def portfolio_return(self):
        """Gets the portfolio_return of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The portfolio_return of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._portfolio_return

    @portfolio_return.setter
    def portfolio_return(self, portfolio_return):
        """Sets the portfolio_return of this RetirementCalculatorPercentCoveredRequest.


        :param portfolio_return: The portfolio_return of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if portfolio_return is None:
            raise ValueError("Invalid value for `portfolio_return`, must not be `None`")  # noqa: E501
        if portfolio_return is not None and portfolio_return < -1:  # noqa: E501
            raise ValueError("Invalid value for `portfolio_return`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._portfolio_return = portfolio_return

    @property
    def deposit_schedule(self):
        """Gets the deposit_schedule of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The deposit_schedule of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: CalculatorDepositSchedule1
        """
        return self._deposit_schedule

    @deposit_schedule.setter
    def deposit_schedule(self, deposit_schedule):
        """Sets the deposit_schedule of this RetirementCalculatorPercentCoveredRequest.


        :param deposit_schedule: The deposit_schedule of this RetirementCalculatorPercentCoveredRequest.  # noqa: E501
        :type: CalculatorDepositSchedule1
        """

        self._deposit_schedule = deposit_schedule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RetirementCalculatorPercentCoveredRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetirementCalculatorPercentCoveredRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RiskScoreRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'post_score': 'bool',
        'weights': 'list[float]',
        'max_answers': 'list[float]',
        'client_id': 'str',
        'answers': 'list[float]',
        'questionnaire_id': 'str'
    }

    attribute_map = {
        'post_score': 'post_score',
        'weights': 'weights',
        'max_answers': 'max_answers',
        'client_id': 'client_id',
        'answers': 'answers',
        'questionnaire_id': 'questionnaire_id'
    }

    def __init__(self, post_score=False, weights=None, max_answers=None, client_id=None, answers=None, questionnaire_id=None):  # noqa: E501
        """RiskScoreRequest - a model defined in Swagger"""  # noqa: E501

        self._post_score = None
        self._weights = None
        self._max_answers = None
        self._client_id = None
        self._answers = None
        self._questionnaire_id = None
        self.discriminator = None

        if post_score is not None:
            self.post_score = post_score
        if weights is not None:
            self.weights = weights
        self.max_answers = max_answers
        if client_id is not None:
            self.client_id = client_id
        if answers is not None:
            self.answers = answers
        if questionnaire_id is not None:
            self.questionnaire_id = questionnaire_id

    @property
    def post_score(self):
        """Gets the post_score of this RiskScoreRequest.  # noqa: E501


        :return: The post_score of this RiskScoreRequest.  # noqa: E501
        :rtype: bool
        """
        return self._post_score

    @post_score.setter
    def post_score(self, post_score):
        """Sets the post_score of this RiskScoreRequest.


        :param post_score: The post_score of this RiskScoreRequest.  # noqa: E501
        :type: bool
        """

        self._post_score = post_score

    @property
    def weights(self):
        """Gets the weights of this RiskScoreRequest.  # noqa: E501


        :return: The weights of this RiskScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._weights

    @weights.setter
    def weights(self, weights):
        """Sets the weights of this RiskScoreRequest.


        :param weights: The weights of this RiskScoreRequest.  # noqa: E501
        :type: list[float]
        """

        self._weights = weights

    @property
    def max_answers(self):
        """Gets the max_answers of this RiskScoreRequest.  # noqa: E501


        :return: The max_answers of this RiskScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._max_answers

    @max_answers.setter
    def max_answers(self, max_answers):
        """Sets the max_answers of this RiskScoreRequest.


        :param max_answers: The max_answers of this RiskScoreRequest.  # noqa: E501
        :type: list[float]
        """
        if max_answers is None:
            raise ValueError("Invalid value for `max_answers`, must not be `None`")  # noqa: E501

        self._max_answers = max_answers

    @property
    def client_id(self):
        """Gets the client_id of this RiskScoreRequest.  # noqa: E501


        :return: The client_id of this RiskScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this RiskScoreRequest.


        :param client_id: The client_id of this RiskScoreRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def answers(self):
        """Gets the answers of this RiskScoreRequest.  # noqa: E501


        :return: The answers of this RiskScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._answers

    @answers.setter
    def answers(self, answers):
        """Sets the answers of this RiskScoreRequest.


        :param answers: The answers of this RiskScoreRequest.  # noqa: E501
        :type: list[float]
        """

        self._answers = answers

    @property
    def questionnaire_id(self):
        """Gets the questionnaire_id of this RiskScoreRequest.  # noqa: E501


        :return: The questionnaire_id of this RiskScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_id

    @questionnaire_id.setter
    def questionnaire_id(self, questionnaire_id):
        """Sets the questionnaire_id of this RiskScoreRequest.


        :param questionnaire_id: The questionnaire_id of this RiskScoreRequest.  # noqa: E501
        :type: str
        """

        self._questionnaire_id = questionnaire_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RiskScoreRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RiskScoreRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PortfolioOptimizationScoreRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'portfolio_tickers': 'list[str]',
        'end_date': 'date',
        'portfolio_id': 'str',
        'market_data_source': 'str',
        'model_id': 'str',
        'create_log': 'bool',
        'opt_config': 'OptConfig1',
        'allocation_id': 'str',
        'tgt_type': 'str',
        'use_proxy_data': 'bool',
        'start_date': 'date',
        'account_id': 'str',
        'aggregation_account_id': 'str',
        'portfolio_weights': 'list[float]'
    }

    attribute_map = {
        'portfolio_tickers': 'portfolio_tickers',
        'end_date': 'end_date',
        'portfolio_id': 'portfolio_id',
        'market_data_source': 'market_data_source',
        'model_id': 'model_id',
        'create_log': 'create_log',
        'opt_config': 'opt_config',
        'allocation_id': 'allocation_id',
        'tgt_type': 'tgt_type',
        'use_proxy_data': 'use_proxy_data',
        'start_date': 'start_date',
        'account_id': 'account_id',
        'aggregation_account_id': 'aggregation_account_id',
        'portfolio_weights': 'portfolio_weights'
    }

    def __init__(self, portfolio_tickers=None, end_date=None, portfolio_id=None, market_data_source='nucleus', model_id=None, create_log=False, opt_config=None, allocation_id=None, tgt_type='return', use_proxy_data=False, start_date=None, account_id=None, aggregation_account_id=None, portfolio_weights=None):  # noqa: E501
        """PortfolioOptimizationScoreRequest - a model defined in Swagger"""  # noqa: E501

        self._portfolio_tickers = None
        self._end_date = None
        self._portfolio_id = None
        self._market_data_source = None
        self._model_id = None
        self._create_log = None
        self._opt_config = None
        self._allocation_id = None
        self._tgt_type = None
        self._use_proxy_data = None
        self._start_date = None
        self._account_id = None
        self._aggregation_account_id = None
        self._portfolio_weights = None
        self.discriminator = None

        if portfolio_tickers is not None:
            self.portfolio_tickers = portfolio_tickers
        if end_date is not None:
            self.end_date = end_date
        if portfolio_id is not None:
            self.portfolio_id = portfolio_id
        if market_data_source is not None:
            self.market_data_source = market_data_source
        if model_id is not None:
            self.model_id = model_id
        if create_log is not None:
            self.create_log = create_log
        if opt_config is not None:
            self.opt_config = opt_config
        if allocation_id is not None:
            self.allocation_id = allocation_id
        if tgt_type is not None:
            self.tgt_type = tgt_type
        if use_proxy_data is not None:
            self.use_proxy_data = use_proxy_data
        if start_date is not None:
            self.start_date = start_date
        if account_id is not None:
            self.account_id = account_id
        if aggregation_account_id is not None:
            self.aggregation_account_id = aggregation_account_id
        if portfolio_weights is not None:
            self.portfolio_weights = portfolio_weights

    @property
    def portfolio_tickers(self):
        """Gets the portfolio_tickers of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The portfolio_tickers of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._portfolio_tickers

    @portfolio_tickers.setter
    def portfolio_tickers(self, portfolio_tickers):
        """Sets the portfolio_tickers of this PortfolioOptimizationScoreRequest.


        :param portfolio_tickers: The portfolio_tickers of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: list[str]
        """

        self._portfolio_tickers = portfolio_tickers

    @property
    def end_date(self):
        """Gets the end_date of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The end_date of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this PortfolioOptimizationScoreRequest.


        :param end_date: The end_date of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def portfolio_id(self):
        """Gets the portfolio_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The portfolio_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._portfolio_id

    @portfolio_id.setter
    def portfolio_id(self, portfolio_id):
        """Sets the portfolio_id of this PortfolioOptimizationScoreRequest.


        :param portfolio_id: The portfolio_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._portfolio_id = portfolio_id

    @property
    def market_data_source(self):
        """Gets the market_data_source of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The market_data_source of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._market_data_source

    @market_data_source.setter
    def market_data_source(self, market_data_source):
        """Sets the market_data_source of this PortfolioOptimizationScoreRequest.


        :param market_data_source: The market_data_source of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["nucleus", "integration"]  # noqa: E501
        if market_data_source not in allowed_values:
            raise ValueError(
                "Invalid value for `market_data_source` ({0}), must be one of {1}"  # noqa: E501
                .format(market_data_source, allowed_values)
            )

        self._market_data_source = market_data_source

    @property
    def model_id(self):
        """Gets the model_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The model_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this PortfolioOptimizationScoreRequest.


        :param model_id: The model_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def create_log(self):
        """Gets the create_log of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The create_log of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_log

    @create_log.setter
    def create_log(self, create_log):
        """Sets the create_log of this PortfolioOptimizationScoreRequest.


        :param create_log: The create_log of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: bool
        """

        self._create_log = create_log

    @property
    def opt_config(self):
        """Gets the opt_config of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The opt_config of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: OptConfig1
        """
        return self._opt_config

    @opt_config.setter
    def opt_config(self, opt_config):
        """Sets the opt_config of this PortfolioOptimizationScoreRequest.


        :param opt_config: The opt_config of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: OptConfig1
        """

        self._opt_config = opt_config

    @property
    def allocation_id(self):
        """Gets the allocation_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The allocation_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_id

    @allocation_id.setter
    def allocation_id(self, allocation_id):
        """Sets the allocation_id of this PortfolioOptimizationScoreRequest.


        :param allocation_id: The allocation_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._allocation_id = allocation_id

    @property
    def tgt_type(self):
        """Gets the tgt_type of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The tgt_type of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._tgt_type

    @tgt_type.setter
    def tgt_type(self, tgt_type):
        """Sets the tgt_type of this PortfolioOptimizationScoreRequest.


        :param tgt_type: The tgt_type of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["risk", "return"]  # noqa: E501
        if tgt_type not in allowed_values:
            raise ValueError(
                "Invalid value for `tgt_type` ({0}), must be one of {1}"  # noqa: E501
                .format(tgt_type, allowed_values)
            )

        self._tgt_type = tgt_type

    @property
    def use_proxy_data(self):
        """Gets the use_proxy_data of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The use_proxy_data of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: bool
        """
        return self._use_proxy_data

    @use_proxy_data.setter
    def use_proxy_data(self, use_proxy_data):
        """Sets the use_proxy_data of this PortfolioOptimizationScoreRequest.


        :param use_proxy_data: The use_proxy_data of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: bool
        """

        self._use_proxy_data = use_proxy_data

    @property
    def start_date(self):
        """Gets the start_date of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The start_date of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this PortfolioOptimizationScoreRequest.


        :param start_date: The start_date of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def account_id(self):
        """Gets the account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this PortfolioOptimizationScoreRequest.


        :param account_id: The account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def aggregation_account_id(self):
        """Gets the aggregation_account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The aggregation_account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._aggregation_account_id

    @aggregation_account_id.setter
    def aggregation_account_id(self, aggregation_account_id):
        """Sets the aggregation_account_id of this PortfolioOptimizationScoreRequest.


        :param aggregation_account_id: The aggregation_account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._aggregation_account_id = aggregation_account_id

    @property
    def portfolio_weights(self):
        """Gets the portfolio_weights of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The portfolio_weights of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._portfolio_weights

    @portfolio_weights.setter
    def portfolio_weights(self, portfolio_weights):
        """Sets the portfolio_weights of this PortfolioOptimizationScoreRequest.


        :param portfolio_weights: The portfolio_weights of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: list[float]
        """

        self._portfolio_weights = portfolio_weights

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PortfolioOptimizationScoreRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PortfolioOptimizationScoreRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AccumulationGoalDepositConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dep_amount': 'float',
        'dep_end_period': 'int',
        'dep_end_reference': 'str',
        'dep_frequency': 'str',
        'dep_start_period': 'int',
        'dep_inflation': 'float',
        'dep_start_reference': 'str'
    }

    attribute_map = {
        'dep_amount': 'dep_amount',
        'dep_end_period': 'dep_end_period',
        'dep_end_reference': 'dep_end_reference',
        'dep_frequency': 'dep_frequency',
        'dep_start_period': 'dep_start_period',
        'dep_inflation': 'dep_inflation',
        'dep_start_reference': 'dep_start_reference'
    }

    def __init__(self, dep_amount=None, dep_end_period=0, dep_end_reference='a_end', dep_frequency='year', dep_start_period=0, dep_inflation=0.0, dep_start_reference='a_start'):  # noqa: E501
        """AccumulationGoalDepositConfig - a model defined in Swagger"""  # noqa: E501

        self._dep_amount = None
        self._dep_end_period = None
        self._dep_end_reference = None
        self._dep_frequency = None
        self._dep_start_period = None
        self._dep_inflation = None
        self._dep_start_reference = None
        self.discriminator = None

        if dep_amount is not None:
            self.dep_amount = dep_amount
        if dep_end_period is not None:
            self.dep_end_period = dep_end_period
        if dep_end_reference is not None:
            self.dep_end_reference = dep_end_reference
        if dep_frequency is not None:
            self.dep_frequency = dep_frequency
        if dep_start_period is not None:
            self.dep_start_period = dep_start_period
        if dep_inflation is not None:
            self.dep_inflation = dep_inflation
        if dep_start_reference is not None:
            self.dep_start_reference = dep_start_reference

    @property
    def dep_amount(self):
        """Gets the dep_amount of this AccumulationGoalDepositConfig.  # noqa: E501


        :return: The dep_amount of this AccumulationGoalDepositConfig.  # noqa: E501
        :rtype: float
        """
        return self._dep_amount

    @dep_amount.setter
    def dep_amount(self, dep_amount):
        """Sets the dep_amount of this AccumulationGoalDepositConfig.


        :param dep_amount: The dep_amount of this AccumulationGoalDepositConfig.  # noqa: E501
        :type: float
        """
        if dep_amount is not None and dep_amount < 0:  # noqa: E501
            raise ValueError("Invalid value for `dep_amount`, must be a value greater than or equal to `0`")  # noqa: E501

        self._dep_amount = dep_amount

    @property
    def dep_end_period(self):
        """Gets the dep_end_period of this AccumulationGoalDepositConfig.  # noqa: E501


        :return: The dep_end_period of this AccumulationGoalDepositConfig.  # noqa: E501
        :rtype: int
        """
        return self._dep_end_period

    @dep_end_period.setter
    def dep_end_period(self, dep_end_period):
        """Sets the dep_end_period of this AccumulationGoalDepositConfig.


        :param dep_end_period: The dep_end_period of this AccumulationGoalDepositConfig.  # noqa: E501
        :type: int
        """

        self._dep_end_period = dep_end_period

    @property
    def dep_end_reference(self):
        """Gets the dep_end_reference of this AccumulationGoalDepositConfig.  # noqa: E501


        :return: The dep_end_reference of this AccumulationGoalDepositConfig.  # noqa: E501
        :rtype: str
        """
        return self._dep_end_reference

    @dep_end_reference.setter
    def dep_end_reference(self, dep_end_reference):
        """Sets the dep_end_reference of this AccumulationGoalDepositConfig.


        :param dep_end_reference: The dep_end_reference of this AccumulationGoalDepositConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["a_start", "a_end"]  # noqa: E501
        if dep_end_reference not in allowed_values:
            raise ValueError(
                "Invalid value for `dep_end_reference` ({0}), must be one of {1}"  # noqa: E501
                .format(dep_end_reference, allowed_values)
            )

        self._dep_end_reference = dep_end_reference

    @property
    def dep_frequency(self):
        """Gets the dep_frequency of this AccumulationGoalDepositConfig.  # noqa: E501


        :return: The dep_frequency of this AccumulationGoalDepositConfig.  # noqa: E501
        :rtype: str
        """
        return self._dep_frequency

    @dep_frequency.setter
    def dep_frequency(self, dep_frequency):
        """Sets the dep_frequency of this AccumulationGoalDepositConfig.


        :param dep_frequency: The dep_frequency of this AccumulationGoalDepositConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["year", "six_months", "quarter", "month", "two_weeks", "week", "day"]  # noqa: E501
        if dep_frequency not in allowed_values:
            raise ValueError(
                "Invalid value for `dep_frequency` ({0}), must be one of {1}"  # noqa: E501
                .format(dep_frequency, allowed_values)
            )

        self._dep_frequency = dep_frequency

    @property
    def dep_start_period(self):
        """Gets the dep_start_period of this AccumulationGoalDepositConfig.  # noqa: E501


        :return: The dep_start_period of this AccumulationGoalDepositConfig.  # noqa: E501
        :rtype: int
        """
        return self._dep_start_period

    @dep_start_period.setter
    def dep_start_period(self, dep_start_period):
        """Sets the dep_start_period of this AccumulationGoalDepositConfig.


        :param dep_start_period: The dep_start_period of this AccumulationGoalDepositConfig.  # noqa: E501
        :type: int
        """

        self._dep_start_period = dep_start_period

    @property
    def dep_inflation(self):
        """Gets the dep_inflation of this AccumulationGoalDepositConfig.  # noqa: E501


        :return: The dep_inflation of this AccumulationGoalDepositConfig.  # noqa: E501
        :rtype: float
        """
        return self._dep_inflation

    @dep_inflation.setter
    def dep_inflation(self, dep_inflation):
        """Sets the dep_inflation of this AccumulationGoalDepositConfig.


        :param dep_inflation: The dep_inflation of this AccumulationGoalDepositConfig.  # noqa: E501
        :type: float
        """
        if dep_inflation is not None and dep_inflation < -1:  # noqa: E501
            raise ValueError("Invalid value for `dep_inflation`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._dep_inflation = dep_inflation

    @property
    def dep_start_reference(self):
        """Gets the dep_start_reference of this AccumulationGoalDepositConfig.  # noqa: E501


        :return: The dep_start_reference of this AccumulationGoalDepositConfig.  # noqa: E501
        :rtype: str
        """
        return self._dep_start_reference

    @dep_start_reference.setter
    def dep_start_reference(self, dep_start_reference):
        """Sets the dep_start_reference of this AccumulationGoalDepositConfig.


        :param dep_start_reference: The dep_start_reference of this AccumulationGoalDepositConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["a_start", "a_end"]  # noqa: E501
        if dep_start_reference not in allowed_values:
            raise ValueError(
                "Invalid value for `dep_start_reference` ({0}), must be one of {1}"  # noqa: E501
                .format(dep_start_reference, allowed_values)
            )

        self._dep_start_reference = dep_start_reference

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccumulationGoalDepositConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccumulationGoalDepositConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CustomerAnalysisRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_date': 'date',
        'benchmark_end_date': 'date',
        'customer_ids': 'list[str]',
        'client_id': 'str',
        'response_limit': 'int',
        'currency_conversion': 'str',
        'start_date': 'date',
        'currency_code': 'str',
        'only_active_customers': 'bool',
        'benchmark_start_date': 'date'
    }

    attribute_map = {
        'end_date': 'end_date',
        'benchmark_end_date': 'benchmark_end_date',
        'customer_ids': 'customer_ids',
        'client_id': 'client_id',
        'response_limit': 'response_limit',
        'currency_conversion': 'currency_conversion',
        'start_date': 'start_date',
        'currency_code': 'currency_code',
        'only_active_customers': 'only_active_customers',
        'benchmark_start_date': 'benchmark_start_date'
    }

    def __init__(self, end_date=None, benchmark_end_date=None, customer_ids=None, client_id=None, response_limit=10, currency_conversion=None, start_date=None, currency_code=None, only_active_customers=False, benchmark_start_date=None):  # noqa: E501
        """CustomerAnalysisRequest - a model defined in Swagger"""  # noqa: E501

        self._end_date = None
        self._benchmark_end_date = None
        self._customer_ids = None
        self._client_id = None
        self._response_limit = None
        self._currency_conversion = None
        self._start_date = None
        self._currency_code = None
        self._only_active_customers = None
        self._benchmark_start_date = None
        self.discriminator = None

        if end_date is not None:
            self.end_date = end_date
        if benchmark_end_date is not None:
            self.benchmark_end_date = benchmark_end_date
        if customer_ids is not None:
            self.customer_ids = customer_ids
        if client_id is not None:
            self.client_id = client_id
        if response_limit is not None:
            self.response_limit = response_limit
        if currency_conversion is not None:
            self.currency_conversion = currency_conversion
        if start_date is not None:
            self.start_date = start_date
        if currency_code is not None:
            self.currency_code = currency_code
        if only_active_customers is not None:
            self.only_active_customers = only_active_customers
        if benchmark_start_date is not None:
            self.benchmark_start_date = benchmark_start_date

    @property
    def end_date(self):
        """Gets the end_date of this CustomerAnalysisRequest.  # noqa: E501


        :return: The end_date of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this CustomerAnalysisRequest.


        :param end_date: The end_date of this CustomerAnalysisRequest.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def benchmark_end_date(self):
        """Gets the benchmark_end_date of this CustomerAnalysisRequest.  # noqa: E501


        :return: The benchmark_end_date of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: date
        """
        return self._benchmark_end_date

    @benchmark_end_date.setter
    def benchmark_end_date(self, benchmark_end_date):
        """Sets the benchmark_end_date of this CustomerAnalysisRequest.


        :param benchmark_end_date: The benchmark_end_date of this CustomerAnalysisRequest.  # noqa: E501
        :type: date
        """

        self._benchmark_end_date = benchmark_end_date

    @property
    def customer_ids(self):
        """Gets the customer_ids of this CustomerAnalysisRequest.  # noqa: E501


        :return: The customer_ids of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._customer_ids

    @customer_ids.setter
    def customer_ids(self, customer_ids):
        """Sets the customer_ids of this CustomerAnalysisRequest.


        :param customer_ids: The customer_ids of this CustomerAnalysisRequest.  # noqa: E501
        :type: list[str]
        """

        self._customer_ids = customer_ids

    @property
    def client_id(self):
        """Gets the client_id of this CustomerAnalysisRequest.  # noqa: E501


        :return: The client_id of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this CustomerAnalysisRequest.


        :param client_id: The client_id of this CustomerAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def response_limit(self):
        """Gets the response_limit of this CustomerAnalysisRequest.  # noqa: E501


        :return: The response_limit of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: int
        """
        return self._response_limit

    @response_limit.setter
    def response_limit(self, response_limit):
        """Sets the response_limit of this CustomerAnalysisRequest.


        :param response_limit: The response_limit of this CustomerAnalysisRequest.  # noqa: E501
        :type: int
        """
        if response_limit is not None and response_limit < 1:  # noqa: E501
            raise ValueError("Invalid value for `response_limit`, must be a value greater than or equal to `1`")  # noqa: E501

        self._response_limit = response_limit

    @property
    def currency_conversion(self):
        """Gets the currency_conversion of this CustomerAnalysisRequest.  # noqa: E501


        :return: The currency_conversion of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_conversion

    @currency_conversion.setter
    def currency_conversion(self, currency_conversion):
        """Sets the currency_conversion of this CustomerAnalysisRequest.


        :param currency_conversion: The currency_conversion of this CustomerAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._currency_conversion = currency_conversion

    @property
    def start_date(self):
        """Gets the start_date of this CustomerAnalysisRequest.  # noqa: E501


        :return: The start_date of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this CustomerAnalysisRequest.


        :param start_date: The start_date of this CustomerAnalysisRequest.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def currency_code(self):
        """Gets the currency_code of this CustomerAnalysisRequest.  # noqa: E501


        :return: The currency_code of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this CustomerAnalysisRequest.


        :param currency_code: The currency_code of this CustomerAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def only_active_customers(self):
        """Gets the only_active_customers of this CustomerAnalysisRequest.  # noqa: E501


        :return: The only_active_customers of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: bool
        """
        return self._only_active_customers

    @only_active_customers.setter
    def only_active_customers(self, only_active_customers):
        """Sets the only_active_customers of this CustomerAnalysisRequest.


        :param only_active_customers: The only_active_customers of this CustomerAnalysisRequest.  # noqa: E501
        :type: bool
        """

        self._only_active_customers = only_active_customers

    @property
    def benchmark_start_date(self):
        """Gets the benchmark_start_date of this CustomerAnalysisRequest.  # noqa: E501


        :return: The benchmark_start_date of this CustomerAnalysisRequest.  # noqa: E501
        :rtype: date
        """
        return self._benchmark_start_date

    @benchmark_start_date.setter
    def benchmark_start_date(self, benchmark_start_date):
        """Sets the benchmark_start_date of this CustomerAnalysisRequest.


        :param benchmark_start_date: The benchmark_start_date of this CustomerAnalysisRequest.  # noqa: E501
        :type: date
        """

        self._benchmark_start_date = benchmark_start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomerAnalysisRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomerAnalysisRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from proton_api.api_client import ApiClient


class FinancialPlanningApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def education_calculator_annual_cost(self, education_calculator_annual_cost_request, **kwargs):  # noqa: E501
        """Education Calculator - Annual Cost  # noqa: E501

        Calculate the achievable education costs  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.education_calculator_annual_cost(education_calculator_annual_cost_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EducationCalculatorAnnualCostRequest education_calculator_annual_cost_request: Request payload for Education Calculator - Annual Cost (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.education_calculator_annual_cost_with_http_info(education_calculator_annual_cost_request, **kwargs)  # noqa: E501
        else:
            (data) = self.education_calculator_annual_cost_with_http_info(education_calculator_annual_cost_request, **kwargs)  # noqa: E501
            return data

    def education_calculator_annual_cost_with_http_info(self, education_calculator_annual_cost_request, **kwargs):  # noqa: E501
        """Education Calculator - Annual Cost  # noqa: E501

        Calculate the achievable education costs  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.education_calculator_annual_cost_with_http_info(education_calculator_annual_cost_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EducationCalculatorAnnualCostRequest education_calculator_annual_cost_request: Request payload for Education Calculator - Annual Cost (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['education_calculator_annual_cost_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method education_calculator_annual_cost" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'education_calculator_annual_cost_request' is set
        if ('education_calculator_annual_cost_request' not in params or
                params['education_calculator_annual_cost_request'] is None):
            raise ValueError("Missing the required parameter `education_calculator_annual_cost_request` when calling `education_calculator_annual_cost`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'education_calculator_annual_cost_request' in params:
            body_params = params['education_calculator_annual_cost_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/education_calculator/annual_cost', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def education_calculator_deposit_amount(self, education_calculator_deposit_amount_request, **kwargs):  # noqa: E501
        """Education Calculator - Deposit Amount  # noqa: E501

        Calculate the necessary periodic deposit amount to achieve education costs  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.education_calculator_deposit_amount(education_calculator_deposit_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EducationCalculatorDepositAmountRequest education_calculator_deposit_amount_request: Request payload for Education Calculator - Deposit Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.education_calculator_deposit_amount_with_http_info(education_calculator_deposit_amount_request, **kwargs)  # noqa: E501
        else:
            (data) = self.education_calculator_deposit_amount_with_http_info(education_calculator_deposit_amount_request, **kwargs)  # noqa: E501
            return data

    def education_calculator_deposit_amount_with_http_info(self, education_calculator_deposit_amount_request, **kwargs):  # noqa: E501
        """Education Calculator - Deposit Amount  # noqa: E501

        Calculate the necessary periodic deposit amount to achieve education costs  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.education_calculator_deposit_amount_with_http_info(education_calculator_deposit_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EducationCalculatorDepositAmountRequest education_calculator_deposit_amount_request: Request payload for Education Calculator - Deposit Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['education_calculator_deposit_amount_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method education_calculator_deposit_amount" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'education_calculator_deposit_amount_request' is set
        if ('education_calculator_deposit_amount_request' not in params or
                params['education_calculator_deposit_amount_request'] is None):
            raise ValueError("Missing the required parameter `education_calculator_deposit_amount_request` when calling `education_calculator_deposit_amount`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'education_calculator_deposit_amount_request' in params:
            body_params = params['education_calculator_deposit_amount_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/education_calculator/deposit_amount', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def education_calculator_percent_covered(self, education_calculator_percent_covered_request, **kwargs):  # noqa: E501
        """Education Calculator - Percent Covered  # noqa: E501

        Calculate the achievable percentage of education costs that can be covered  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.education_calculator_percent_covered(education_calculator_percent_covered_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EducationCalculatorPercentCoveredRequest education_calculator_percent_covered_request: Request payload for Education Calculator - Percent Covered (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.education_calculator_percent_covered_with_http_info(education_calculator_percent_covered_request, **kwargs)  # noqa: E501
        else:
            (data) = self.education_calculator_percent_covered_with_http_info(education_calculator_percent_covered_request, **kwargs)  # noqa: E501
            return data

    def education_calculator_percent_covered_with_http_info(self, education_calculator_percent_covered_request, **kwargs):  # noqa: E501
        """Education Calculator - Percent Covered  # noqa: E501

        Calculate the achievable percentage of education costs that can be covered  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.education_calculator_percent_covered_with_http_info(education_calculator_percent_covered_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param EducationCalculatorPercentCoveredRequest education_calculator_percent_covered_request: Request payload for Education Calculator - Percent Covered (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['education_calculator_percent_covered_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method education_calculator_percent_covered" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'education_calculator_percent_covered_request' is set
        if ('education_calculator_percent_covered_request' not in params or
                params['education_calculator_percent_covered_request'] is None):
            raise ValueError("Missing the required parameter `education_calculator_percent_covered_request` when calling `education_calculator_percent_covered`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'education_calculator_percent_covered_request' in params:
            body_params = params['education_calculator_percent_covered_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/education_calculator/percent_covered', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def mortgage_calculator_down_payment(self, mortgage_calculator_down_payment_request, **kwargs):  # noqa: E501
        """Mortgage Calculator - Down Payment  # noqa: E501

        Calculate the necessary down payment for the mortgage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mortgage_calculator_down_payment(mortgage_calculator_down_payment_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MortgageCalculatorDownPaymentRequest mortgage_calculator_down_payment_request: Request payload for Mortgage Calculator - Down Payment (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.mortgage_calculator_down_payment_with_http_info(mortgage_calculator_down_payment_request, **kwargs)  # noqa: E501
        else:
            (data) = self.mortgage_calculator_down_payment_with_http_info(mortgage_calculator_down_payment_request, **kwargs)  # noqa: E501
            return data

    def mortgage_calculator_down_payment_with_http_info(self, mortgage_calculator_down_payment_request, **kwargs):  # noqa: E501
        """Mortgage Calculator - Down Payment  # noqa: E501

        Calculate the necessary down payment for the mortgage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mortgage_calculator_down_payment_with_http_info(mortgage_calculator_down_payment_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MortgageCalculatorDownPaymentRequest mortgage_calculator_down_payment_request: Request payload for Mortgage Calculator - Down Payment (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['mortgage_calculator_down_payment_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mortgage_calculator_down_payment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'mortgage_calculator_down_payment_request' is set
        if ('mortgage_calculator_down_payment_request' not in params or
                params['mortgage_calculator_down_payment_request'] is None):
            raise ValueError("Missing the required parameter `mortgage_calculator_down_payment_request` when calling `mortgage_calculator_down_payment`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mortgage_calculator_down_payment_request' in params:
            body_params = params['mortgage_calculator_down_payment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/mortgage_calculator/down_payment', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def mortgage_calculator_home_price(self, mortgage_calculator_home_price_request, **kwargs):  # noqa: E501
        """Mortgage Calculator - Home Price  # noqa: E501

        Calculate the achievable home price for the mortgage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mortgage_calculator_home_price(mortgage_calculator_home_price_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MortgageCalculatorHomePriceRequest mortgage_calculator_home_price_request: Request payload for Mortgage Calculator - Home Price (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.mortgage_calculator_home_price_with_http_info(mortgage_calculator_home_price_request, **kwargs)  # noqa: E501
        else:
            (data) = self.mortgage_calculator_home_price_with_http_info(mortgage_calculator_home_price_request, **kwargs)  # noqa: E501
            return data

    def mortgage_calculator_home_price_with_http_info(self, mortgage_calculator_home_price_request, **kwargs):  # noqa: E501
        """Mortgage Calculator - Home Price  # noqa: E501

        Calculate the achievable home price for the mortgage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mortgage_calculator_home_price_with_http_info(mortgage_calculator_home_price_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MortgageCalculatorHomePriceRequest mortgage_calculator_home_price_request: Request payload for Mortgage Calculator - Home Price (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['mortgage_calculator_home_price_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mortgage_calculator_home_price" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'mortgage_calculator_home_price_request' is set
        if ('mortgage_calculator_home_price_request' not in params or
                params['mortgage_calculator_home_price_request'] is None):
            raise ValueError("Missing the required parameter `mortgage_calculator_home_price_request` when calling `mortgage_calculator_home_price`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mortgage_calculator_home_price_request' in params:
            body_params = params['mortgage_calculator_home_price_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/mortgage_calculator/home_price', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def mortgage_calculator_periodic_payment(self, mortgage_calculator_periodic_payment_request, **kwargs):  # noqa: E501
        """Mortgage Calculator - Periodic Payment  # noqa: E501

        Calculate the periodic payment for the mortgage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mortgage_calculator_periodic_payment(mortgage_calculator_periodic_payment_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MortgageCalculatorPeriodicPaymentRequest mortgage_calculator_periodic_payment_request: Request payload for Mortgage Calculator - Periodic Payment (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.mortgage_calculator_periodic_payment_with_http_info(mortgage_calculator_periodic_payment_request, **kwargs)  # noqa: E501
        else:
            (data) = self.mortgage_calculator_periodic_payment_with_http_info(mortgage_calculator_periodic_payment_request, **kwargs)  # noqa: E501
            return data

    def mortgage_calculator_periodic_payment_with_http_info(self, mortgage_calculator_periodic_payment_request, **kwargs):  # noqa: E501
        """Mortgage Calculator - Periodic Payment  # noqa: E501

        Calculate the periodic payment for the mortgage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mortgage_calculator_periodic_payment_with_http_info(mortgage_calculator_periodic_payment_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MortgageCalculatorPeriodicPaymentRequest mortgage_calculator_periodic_payment_request: Request payload for Mortgage Calculator - Periodic Payment (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['mortgage_calculator_periodic_payment_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mortgage_calculator_periodic_payment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'mortgage_calculator_periodic_payment_request' is set
        if ('mortgage_calculator_periodic_payment_request' not in params or
                params['mortgage_calculator_periodic_payment_request'] is None):
            raise ValueError("Missing the required parameter `mortgage_calculator_periodic_payment_request` when calling `mortgage_calculator_periodic_payment`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mortgage_calculator_periodic_payment_request' in params:
            body_params = params['mortgage_calculator_periodic_payment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/mortgage_calculator/periodic_payment', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def purchase_calculator_amount(self, purchase_calculator_amount_request, **kwargs):  # noqa: E501
        """Purchase Calculator - Amount  # noqa: E501

        Calculate the achievable purchase amount  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.purchase_calculator_amount(purchase_calculator_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PurchaseCalculatorAmountRequest purchase_calculator_amount_request: Request payload for Purchase Calculator - Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.purchase_calculator_amount_with_http_info(purchase_calculator_amount_request, **kwargs)  # noqa: E501
        else:
            (data) = self.purchase_calculator_amount_with_http_info(purchase_calculator_amount_request, **kwargs)  # noqa: E501
            return data

    def purchase_calculator_amount_with_http_info(self, purchase_calculator_amount_request, **kwargs):  # noqa: E501
        """Purchase Calculator - Amount  # noqa: E501

        Calculate the achievable purchase amount  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.purchase_calculator_amount_with_http_info(purchase_calculator_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PurchaseCalculatorAmountRequest purchase_calculator_amount_request: Request payload for Purchase Calculator - Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['purchase_calculator_amount_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method purchase_calculator_amount" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'purchase_calculator_amount_request' is set
        if ('purchase_calculator_amount_request' not in params or
                params['purchase_calculator_amount_request'] is None):
            raise ValueError("Missing the required parameter `purchase_calculator_amount_request` when calling `purchase_calculator_amount`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'purchase_calculator_amount_request' in params:
            body_params = params['purchase_calculator_amount_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/purchase_calculator/amount', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def purchase_calculator_deposit_amount(self, purchase_calculator_deposit_amount_request, **kwargs):  # noqa: E501
        """Purchase Calculator - Deposit Amount  # noqa: E501

        Calculate the necessary periodic deposit amount to achieve the purchase amount  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.purchase_calculator_deposit_amount(purchase_calculator_deposit_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PurchaseCalculatorDepositAmountRequest purchase_calculator_deposit_amount_request: Request payload for Purchase Calculator - Deposit Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.purchase_calculator_deposit_amount_with_http_info(purchase_calculator_deposit_amount_request, **kwargs)  # noqa: E501
        else:
            (data) = self.purchase_calculator_deposit_amount_with_http_info(purchase_calculator_deposit_amount_request, **kwargs)  # noqa: E501
            return data

    def purchase_calculator_deposit_amount_with_http_info(self, purchase_calculator_deposit_amount_request, **kwargs):  # noqa: E501
        """Purchase Calculator - Deposit Amount  # noqa: E501

        Calculate the necessary periodic deposit amount to achieve the purchase amount  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.purchase_calculator_deposit_amount_with_http_info(purchase_calculator_deposit_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PurchaseCalculatorDepositAmountRequest purchase_calculator_deposit_amount_request: Request payload for Purchase Calculator - Deposit Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['purchase_calculator_deposit_amount_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method purchase_calculator_deposit_amount" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'purchase_calculator_deposit_amount_request' is set
        if ('purchase_calculator_deposit_amount_request' not in params or
                params['purchase_calculator_deposit_amount_request'] is None):
            raise ValueError("Missing the required parameter `purchase_calculator_deposit_amount_request` when calling `purchase_calculator_deposit_amount`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'purchase_calculator_deposit_amount_request' in params:
            body_params = params['purchase_calculator_deposit_amount_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/purchase_calculator/deposit_amount', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def purchase_calculator_horizon(self, purchase_calculator_horizon_request, **kwargs):  # noqa: E501
        """Purchase Calculator - Horizon  # noqa: E501

        Calculate the necessary time horizon to achieve the purchase amount  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.purchase_calculator_horizon(purchase_calculator_horizon_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PurchaseCalculatorHorizonRequest purchase_calculator_horizon_request: Request payload for Purchase Calculator - Horizon (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.purchase_calculator_horizon_with_http_info(purchase_calculator_horizon_request, **kwargs)  # noqa: E501
        else:
            (data) = self.purchase_calculator_horizon_with_http_info(purchase_calculator_horizon_request, **kwargs)  # noqa: E501
            return data

    def purchase_calculator_horizon_with_http_info(self, purchase_calculator_horizon_request, **kwargs):  # noqa: E501
        """Purchase Calculator - Horizon  # noqa: E501

        Calculate the necessary time horizon to achieve the purchase amount  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.purchase_calculator_horizon_with_http_info(purchase_calculator_horizon_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PurchaseCalculatorHorizonRequest purchase_calculator_horizon_request: Request payload for Purchase Calculator - Horizon (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['purchase_calculator_horizon_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method purchase_calculator_horizon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'purchase_calculator_horizon_request' is set
        if ('purchase_calculator_horizon_request' not in params or
                params['purchase_calculator_horizon_request'] is None):
            raise ValueError("Missing the required parameter `purchase_calculator_horizon_request` when calling `purchase_calculator_horizon`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'purchase_calculator_horizon_request' in params:
            body_params = params['purchase_calculator_horizon_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/purchase_calculator/horizon', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retirement_calculator_deposit_amount(self, retirement_calculator_deposit_amount_request, **kwargs):  # noqa: E501
        """Retirement Calculator - Deposit Amount  # noqa: E501

        Calculate the necessary period deposit amount to achieve the retirement expenses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retirement_calculator_deposit_amount(retirement_calculator_deposit_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RetirementCalculatorDepositAmountRequest retirement_calculator_deposit_amount_request: Request payload for Retirement Calculator - Deposit AMount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retirement_calculator_deposit_amount_with_http_info(retirement_calculator_deposit_amount_request, **kwargs)  # noqa: E501
        else:
            (data) = self.retirement_calculator_deposit_amount_with_http_info(retirement_calculator_deposit_amount_request, **kwargs)  # noqa: E501
            return data

    def retirement_calculator_deposit_amount_with_http_info(self, retirement_calculator_deposit_amount_request, **kwargs):  # noqa: E501
        """Retirement Calculator - Deposit Amount  # noqa: E501

        Calculate the necessary period deposit amount to achieve the retirement expenses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retirement_calculator_deposit_amount_with_http_info(retirement_calculator_deposit_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RetirementCalculatorDepositAmountRequest retirement_calculator_deposit_amount_request: Request payload for Retirement Calculator - Deposit AMount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['retirement_calculator_deposit_amount_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retirement_calculator_deposit_amount" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'retirement_calculator_deposit_amount_request' is set
        if ('retirement_calculator_deposit_amount_request' not in params or
                params['retirement_calculator_deposit_amount_request'] is None):
            raise ValueError("Missing the required parameter `retirement_calculator_deposit_amount_request` when calling `retirement_calculator_deposit_amount`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'retirement_calculator_deposit_amount_request' in params:
            body_params = params['retirement_calculator_deposit_amount_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/retirement_calculator/deposit_amount', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retirement_calculator_expenses(self, retirement_calculator_expenses_request, **kwargs):  # noqa: E501
        """Retirement Calculator - Expenses  # noqa: E501

        Calculate the achievable retirement expenses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retirement_calculator_expenses(retirement_calculator_expenses_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RetirementCalculatorExpensesRequest retirement_calculator_expenses_request: Request payload for Retirement Calculator - Expenses (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retirement_calculator_expenses_with_http_info(retirement_calculator_expenses_request, **kwargs)  # noqa: E501
        else:
            (data) = self.retirement_calculator_expenses_with_http_info(retirement_calculator_expenses_request, **kwargs)  # noqa: E501
            return data

    def retirement_calculator_expenses_with_http_info(self, retirement_calculator_expenses_request, **kwargs):  # noqa: E501
        """Retirement Calculator - Expenses  # noqa: E501

        Calculate the achievable retirement expenses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retirement_calculator_expenses_with_http_info(retirement_calculator_expenses_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RetirementCalculatorExpensesRequest retirement_calculator_expenses_request: Request payload for Retirement Calculator - Expenses (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['retirement_calculator_expenses_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retirement_calculator_expenses" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'retirement_calculator_expenses_request' is set
        if ('retirement_calculator_expenses_request' not in params or
                params['retirement_calculator_expenses_request'] is None):
            raise ValueError("Missing the required parameter `retirement_calculator_expenses_request` when calling `retirement_calculator_expenses`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'retirement_calculator_expenses_request' in params:
            body_params = params['retirement_calculator_expenses_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/retirement_calculator/expenses', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retirement_calculator_percent_covered(self, retirement_calculator_percent_covered_request, **kwargs):  # noqa: E501
        """Retirement Calculator - Percent Covered  # noqa: E501

        Calculate the achievable percentage of retirement expenses that can be covered  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retirement_calculator_percent_covered(retirement_calculator_percent_covered_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RetirementCalculatorPercentCoveredRequest retirement_calculator_percent_covered_request: Request payload for Retirement Calculator - Percent Covered (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retirement_calculator_percent_covered_with_http_info(retirement_calculator_percent_covered_request, **kwargs)  # noqa: E501
        else:
            (data) = self.retirement_calculator_percent_covered_with_http_info(retirement_calculator_percent_covered_request, **kwargs)  # noqa: E501
            return data

    def retirement_calculator_percent_covered_with_http_info(self, retirement_calculator_percent_covered_request, **kwargs):  # noqa: E501
        """Retirement Calculator - Percent Covered  # noqa: E501

        Calculate the achievable percentage of retirement expenses that can be covered  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retirement_calculator_percent_covered_with_http_info(retirement_calculator_percent_covered_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RetirementCalculatorPercentCoveredRequest retirement_calculator_percent_covered_request: Request payload for Retirement Calculator - Percent Covered (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['retirement_calculator_percent_covered_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retirement_calculator_percent_covered" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'retirement_calculator_percent_covered_request' is set
        if ('retirement_calculator_percent_covered_request' not in params or
                params['retirement_calculator_percent_covered_request'] is None):
            raise ValueError("Missing the required parameter `retirement_calculator_percent_covered_request` when calling `retirement_calculator_percent_covered`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'retirement_calculator_percent_covered_request' in params:
            body_params = params['retirement_calculator_percent_covered_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/retirement_calculator/percent_covered', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class EducationConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_age': 'int',
        'total_annual_cost': 'float',
        'start_age': 'int'
    }

    attribute_map = {
        'end_age': 'end_age',
        'total_annual_cost': 'total_annual_cost',
        'start_age': 'start_age'
    }

    def __init__(self, end_age=None, total_annual_cost=None, start_age=None):  # noqa: E501
        """EducationConfig - a model defined in Swagger"""  # noqa: E501

        self._end_age = None
        self._total_annual_cost = None
        self._start_age = None
        self.discriminator = None

        self.end_age = end_age
        self.total_annual_cost = total_annual_cost
        self.start_age = start_age

    @property
    def end_age(self):
        """Gets the end_age of this EducationConfig.  # noqa: E501


        :return: The end_age of this EducationConfig.  # noqa: E501
        :rtype: int
        """
        return self._end_age

    @end_age.setter
    def end_age(self, end_age):
        """Sets the end_age of this EducationConfig.


        :param end_age: The end_age of this EducationConfig.  # noqa: E501
        :type: int
        """
        if end_age is None:
            raise ValueError("Invalid value for `end_age`, must not be `None`")  # noqa: E501
        if end_age is not None and end_age < 0:  # noqa: E501
            raise ValueError("Invalid value for `end_age`, must be a value greater than or equal to `0`")  # noqa: E501

        self._end_age = end_age

    @property
    def total_annual_cost(self):
        """Gets the total_annual_cost of this EducationConfig.  # noqa: E501


        :return: The total_annual_cost of this EducationConfig.  # noqa: E501
        :rtype: float
        """
        return self._total_annual_cost

    @total_annual_cost.setter
    def total_annual_cost(self, total_annual_cost):
        """Sets the total_annual_cost of this EducationConfig.


        :param total_annual_cost: The total_annual_cost of this EducationConfig.  # noqa: E501
        :type: float
        """
        if total_annual_cost is None:
            raise ValueError("Invalid value for `total_annual_cost`, must not be `None`")  # noqa: E501
        if total_annual_cost is not None and total_annual_cost < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_annual_cost`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_annual_cost = total_annual_cost

    @property
    def start_age(self):
        """Gets the start_age of this EducationConfig.  # noqa: E501


        :return: The start_age of this EducationConfig.  # noqa: E501
        :rtype: int
        """
        return self._start_age

    @start_age.setter
    def start_age(self, start_age):
        """Sets the start_age of this EducationConfig.


        :param start_age: The start_age of this EducationConfig.  # noqa: E501
        :type: int
        """
        if start_age is None:
            raise ValueError("Invalid value for `start_age`, must not be `None`")  # noqa: E501
        if start_age is not None and start_age < 0:  # noqa: E501
            raise ValueError("Invalid value for `start_age`, must be a value greater than or equal to `0`")  # noqa: E501

        self._start_age = start_age

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EducationConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EducationConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class LifeInsuranceNeedsCalculatorRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'children_education_config': 'list[ChildrenEducationConfig]',
        'liquid_assets': 'float',
        'other_debt': 'float',
        'client_id': 'str',
        'tax_rate': 'float',
        'end_of_life_expenses': 'float',
        'mortgage_balance': 'float',
        'income_config': 'list[IncomeConfig]',
        'beneficiary_bequest_config': 'list[BeneficiaryBequestConfig]',
        'margin_of_error': 'float',
        'education_inflation_rate': 'float',
        'interest_rate': 'float',
        'existing_life_insurance': 'float',
        'benefit_amount_rounding': 'int',
        'general_inflation_rate': 'float'
    }

    attribute_map = {
        'children_education_config': 'children_education_config',
        'liquid_assets': 'liquid_assets',
        'other_debt': 'other_debt',
        'client_id': 'client_id',
        'tax_rate': 'tax_rate',
        'end_of_life_expenses': 'end_of_life_expenses',
        'mortgage_balance': 'mortgage_balance',
        'income_config': 'income_config',
        'beneficiary_bequest_config': 'beneficiary_bequest_config',
        'margin_of_error': 'margin_of_error',
        'education_inflation_rate': 'education_inflation_rate',
        'interest_rate': 'interest_rate',
        'existing_life_insurance': 'existing_life_insurance',
        'benefit_amount_rounding': 'benefit_amount_rounding',
        'general_inflation_rate': 'general_inflation_rate'
    }

    def __init__(self, children_education_config=None, liquid_assets=None, other_debt=None, client_id=None, tax_rate=0.0, end_of_life_expenses=None, mortgage_balance=None, income_config=None, beneficiary_bequest_config=None, margin_of_error=0.0, education_inflation_rate=0.0, interest_rate=None, existing_life_insurance=None, benefit_amount_rounding=0, general_inflation_rate=0.0):  # noqa: E501
        """LifeInsuranceNeedsCalculatorRequest - a model defined in Swagger"""  # noqa: E501

        self._children_education_config = None
        self._liquid_assets = None
        self._other_debt = None
        self._client_id = None
        self._tax_rate = None
        self._end_of_life_expenses = None
        self._mortgage_balance = None
        self._income_config = None
        self._beneficiary_bequest_config = None
        self._margin_of_error = None
        self._education_inflation_rate = None
        self._interest_rate = None
        self._existing_life_insurance = None
        self._benefit_amount_rounding = None
        self._general_inflation_rate = None
        self.discriminator = None

        if children_education_config is not None:
            self.children_education_config = children_education_config
        if liquid_assets is not None:
            self.liquid_assets = liquid_assets
        if other_debt is not None:
            self.other_debt = other_debt
        if client_id is not None:
            self.client_id = client_id
        if tax_rate is not None:
            self.tax_rate = tax_rate
        if end_of_life_expenses is not None:
            self.end_of_life_expenses = end_of_life_expenses
        if mortgage_balance is not None:
            self.mortgage_balance = mortgage_balance
        if income_config is not None:
            self.income_config = income_config
        if beneficiary_bequest_config is not None:
            self.beneficiary_bequest_config = beneficiary_bequest_config
        if margin_of_error is not None:
            self.margin_of_error = margin_of_error
        if education_inflation_rate is not None:
            self.education_inflation_rate = education_inflation_rate
        self.interest_rate = interest_rate
        if existing_life_insurance is not None:
            self.existing_life_insurance = existing_life_insurance
        if benefit_amount_rounding is not None:
            self.benefit_amount_rounding = benefit_amount_rounding
        if general_inflation_rate is not None:
            self.general_inflation_rate = general_inflation_rate

    @property
    def children_education_config(self):
        """Gets the children_education_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The children_education_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: list[ChildrenEducationConfig]
        """
        return self._children_education_config

    @children_education_config.setter
    def children_education_config(self, children_education_config):
        """Sets the children_education_config of this LifeInsuranceNeedsCalculatorRequest.


        :param children_education_config: The children_education_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: list[ChildrenEducationConfig]
        """

        self._children_education_config = children_education_config

    @property
    def liquid_assets(self):
        """Gets the liquid_assets of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The liquid_assets of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._liquid_assets

    @liquid_assets.setter
    def liquid_assets(self, liquid_assets):
        """Sets the liquid_assets of this LifeInsuranceNeedsCalculatorRequest.


        :param liquid_assets: The liquid_assets of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if liquid_assets is not None and liquid_assets < 0:  # noqa: E501
            raise ValueError("Invalid value for `liquid_assets`, must be a value greater than or equal to `0`")  # noqa: E501

        self._liquid_assets = liquid_assets

    @property
    def other_debt(self):
        """Gets the other_debt of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The other_debt of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._other_debt

    @other_debt.setter
    def other_debt(self, other_debt):
        """Sets the other_debt of this LifeInsuranceNeedsCalculatorRequest.


        :param other_debt: The other_debt of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if other_debt is not None and other_debt < 0:  # noqa: E501
            raise ValueError("Invalid value for `other_debt`, must be a value greater than or equal to `0`")  # noqa: E501

        self._other_debt = other_debt

    @property
    def client_id(self):
        """Gets the client_id of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The client_id of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this LifeInsuranceNeedsCalculatorRequest.


        :param client_id: The client_id of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def tax_rate(self):
        """Gets the tax_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The tax_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, tax_rate):
        """Sets the tax_rate of this LifeInsuranceNeedsCalculatorRequest.


        :param tax_rate: The tax_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if tax_rate is not None and tax_rate > 1:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value less than or equal to `1`")  # noqa: E501
        if tax_rate is not None and tax_rate < 0:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._tax_rate = tax_rate

    @property
    def end_of_life_expenses(self):
        """Gets the end_of_life_expenses of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The end_of_life_expenses of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._end_of_life_expenses

    @end_of_life_expenses.setter
    def end_of_life_expenses(self, end_of_life_expenses):
        """Sets the end_of_life_expenses of this LifeInsuranceNeedsCalculatorRequest.


        :param end_of_life_expenses: The end_of_life_expenses of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if end_of_life_expenses is not None and end_of_life_expenses < 0:  # noqa: E501
            raise ValueError("Invalid value for `end_of_life_expenses`, must be a value greater than or equal to `0`")  # noqa: E501

        self._end_of_life_expenses = end_of_life_expenses

    @property
    def mortgage_balance(self):
        """Gets the mortgage_balance of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The mortgage_balance of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._mortgage_balance

    @mortgage_balance.setter
    def mortgage_balance(self, mortgage_balance):
        """Sets the mortgage_balance of this LifeInsuranceNeedsCalculatorRequest.


        :param mortgage_balance: The mortgage_balance of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if mortgage_balance is not None and mortgage_balance < 0:  # noqa: E501
            raise ValueError("Invalid value for `mortgage_balance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._mortgage_balance = mortgage_balance

    @property
    def income_config(self):
        """Gets the income_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The income_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: list[IncomeConfig]
        """
        return self._income_config

    @income_config.setter
    def income_config(self, income_config):
        """Sets the income_config of this LifeInsuranceNeedsCalculatorRequest.


        :param income_config: The income_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: list[IncomeConfig]
        """

        self._income_config = income_config

    @property
    def beneficiary_bequest_config(self):
        """Gets the beneficiary_bequest_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The beneficiary_bequest_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: list[BeneficiaryBequestConfig]
        """
        return self._beneficiary_bequest_config

    @beneficiary_bequest_config.setter
    def beneficiary_bequest_config(self, beneficiary_bequest_config):
        """Sets the beneficiary_bequest_config of this LifeInsuranceNeedsCalculatorRequest.


        :param beneficiary_bequest_config: The beneficiary_bequest_config of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: list[BeneficiaryBequestConfig]
        """

        self._beneficiary_bequest_config = beneficiary_bequest_config

    @property
    def margin_of_error(self):
        """Gets the margin_of_error of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The margin_of_error of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._margin_of_error

    @margin_of_error.setter
    def margin_of_error(self, margin_of_error):
        """Sets the margin_of_error of this LifeInsuranceNeedsCalculatorRequest.


        :param margin_of_error: The margin_of_error of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if margin_of_error is not None and margin_of_error < 0:  # noqa: E501
            raise ValueError("Invalid value for `margin_of_error`, must be a value greater than or equal to `0`")  # noqa: E501

        self._margin_of_error = margin_of_error

    @property
    def education_inflation_rate(self):
        """Gets the education_inflation_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The education_inflation_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._education_inflation_rate

    @education_inflation_rate.setter
    def education_inflation_rate(self, education_inflation_rate):
        """Sets the education_inflation_rate of this LifeInsuranceNeedsCalculatorRequest.


        :param education_inflation_rate: The education_inflation_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if education_inflation_rate is not None and education_inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `education_inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._education_inflation_rate = education_inflation_rate

    @property
    def interest_rate(self):
        """Gets the interest_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The interest_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._interest_rate

    @interest_rate.setter
    def interest_rate(self, interest_rate):
        """Sets the interest_rate of this LifeInsuranceNeedsCalculatorRequest.


        :param interest_rate: The interest_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if interest_rate is None:
            raise ValueError("Invalid value for `interest_rate`, must not be `None`")  # noqa: E501
        if interest_rate is not None and interest_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `interest_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._interest_rate = interest_rate

    @property
    def existing_life_insurance(self):
        """Gets the existing_life_insurance of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The existing_life_insurance of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._existing_life_insurance

    @existing_life_insurance.setter
    def existing_life_insurance(self, existing_life_insurance):
        """Sets the existing_life_insurance of this LifeInsuranceNeedsCalculatorRequest.


        :param existing_life_insurance: The existing_life_insurance of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if existing_life_insurance is not None and existing_life_insurance < 0:  # noqa: E501
            raise ValueError("Invalid value for `existing_life_insurance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._existing_life_insurance = existing_life_insurance

    @property
    def benefit_amount_rounding(self):
        """Gets the benefit_amount_rounding of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The benefit_amount_rounding of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: int
        """
        return self._benefit_amount_rounding

    @benefit_amount_rounding.setter
    def benefit_amount_rounding(self, benefit_amount_rounding):
        """Sets the benefit_amount_rounding of this LifeInsuranceNeedsCalculatorRequest.


        :param benefit_amount_rounding: The benefit_amount_rounding of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: int
        """
        if benefit_amount_rounding is not None and benefit_amount_rounding > 12:  # noqa: E501
            raise ValueError("Invalid value for `benefit_amount_rounding`, must be a value less than or equal to `12`")  # noqa: E501
        if benefit_amount_rounding is not None and benefit_amount_rounding < 0:  # noqa: E501
            raise ValueError("Invalid value for `benefit_amount_rounding`, must be a value greater than or equal to `0`")  # noqa: E501

        self._benefit_amount_rounding = benefit_amount_rounding

    @property
    def general_inflation_rate(self):
        """Gets the general_inflation_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501


        :return: The general_inflation_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :rtype: float
        """
        return self._general_inflation_rate

    @general_inflation_rate.setter
    def general_inflation_rate(self, general_inflation_rate):
        """Sets the general_inflation_rate of this LifeInsuranceNeedsCalculatorRequest.


        :param general_inflation_rate: The general_inflation_rate of this LifeInsuranceNeedsCalculatorRequest.  # noqa: E501
        :type: float
        """
        if general_inflation_rate is not None and general_inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `general_inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._general_inflation_rate = general_inflation_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LifeInsuranceNeedsCalculatorRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LifeInsuranceNeedsCalculatorRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
